@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0049';
+our $VERSION = '0.0050';
 
 use Moo;
 use strictures 2;
@@ -411,18 +411,23 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0049
+version 0.0050
 
 =head1 SYNOPSIS
 
   use Synth::Config ();
 
-  my $model = 'Moog Matriarch';
-
+  my $model = 'Modular';
   my $synth = Synth::Config->new(model => $model);
 
-  my $patch = 'My favorite setting';
+  # populate the database with patch settings from a YAML file or string
+  my $patches = $synth->import_yaml(
+      file    => "$model.yaml", # or string => ...
+      patches => ['Simple 001', 'Simple 002' ],
+  );
 
+  # populate the database with individual settings
+  my $patch = 'My favorite setting';
   my $id1 = $synth->make_setting(name => $patch, group => 'filter', etc => '...');
   my $id2 = $synth->make_setting(name => $patch, group => 'sequencer', etc => '...');
 
